@@ -32,7 +32,7 @@ OpenMeteoWeatherProvider::OpenMeteoWeatherProvider()
             &OpenMeteoWeatherProvider::onResponse);
 }
 
-void OpenMeteoWeatherProvider::getData(QList<QGeoCoordinate> locations, QVariantList userData)
+void OpenMeteoWeatherProvider::getData(QList<QGeoCoordinate> locations, QVariantList userData, QString forecastDays)
 {
     QStringList latitudes;
     QStringList longitudes;
@@ -61,7 +61,7 @@ void OpenMeteoWeatherProvider::getData(QList<QGeoCoordinate> locations, QVariant
                        "min,apparent_temperature_max,precipitation_sum,sunshine_duration,"
                        "rain_sum,showers_sum,snowfall_sum,precipitation_probability_max,wind_speed_"
                        "10m_max,wind_direction_10m_dominant,uv_index_max");
-    query.addQueryItem("forecast_days", "10"); // up to 16
+    query.addQueryItem("forecast_days", forecastDays); // up to 16
     query.addQueryItem("temperature_unit", "celsius");
     query.addQueryItem("wind_speed_unit", "ms");
     query.addQueryItem("precipitation_unit", "mm");
