@@ -28,7 +28,7 @@ class WeatherDataProviderInterface
 public:
     virtual ~WeatherDataProviderInterface() = default;
 
-    virtual void getData(QList<QGeoCoordinate> locations, QVariantList userData) = 0;
+    virtual void getData(QList<QGeoCoordinate> locations, QVariantList userData, QString forecastDays) = 0;
 
 signals:
     virtual void dataReceived(QGeoCoordinate coordinate, DataPoint current, QList<DataDay> forecast,
